def bruno():
    print('Va voir ce que dit le standard CPP17 : http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2017/n4713.pdf')


def signal_handler(signum, frame):
    print(f'[STAN] Désolé mon réveil était cassé...')
    return
